## Typing stubs for mock

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`mock`](https://github.com/testing-cabal/mock) package. It can be used by type checkers
to check code that uses `mock`. This version of
`types-mock` aims to provide accurate annotations for
`mock==5.2.*`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/mock`](https://github.com/python/typeshed/tree/main/stubs/mock)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.20.0
* [pyright](https://github.com/microsoft/pyright) 1.1.408

It was generated from typeshed commit
[`4ab04d22631e5842838528ceaae19c3c532cdd43`](https://github.com/python/typeshed/commit/4ab04d22631e5842838528ceaae19c3c532cdd43).